<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:lxslt="http://xml.apache.org/xslt" xmlns:redirect="com.scenari.xsldom.xalan.lib.Redirect" xmlns:java="http://xml.apache.org/xslt/java" extension-element-prefixes="redirect java lxslt ">
<xsl:output method="xml" indent="no"/>
<xsl:param name="vDialog"/>
<xsl:param name="vAgent"/>

			<xsl:template match="div[@class='nonRedundantList']">
    <xsl:apply-templates mode="nonRedundantList" />
</xsl:template>

<xsl:template match="div[@class='nonRedundantList']/*" mode="nonRedundantList">
    <xsl:if test="not(preceding-sibling::*[normalize-space(.) = normalize-space(current())])">
         <xsl:apply-templates select="." />
    </xsl:if> 
</xsl:template>

			<xsl:template match="head">
	<xsl:copy>
		<xsl:apply-templates select="@*"/>
		<xsl:apply-overlays/>
		<xsl:apply-templates/>
		<xsl:apply-templates select="../body" mode="bookmarks"/>
	</xsl:copy>
</xsl:template>

<xsl:template match="*" mode="bookmarks">
	<xsl:apply-templates mode="bookmarks"/>
</xsl:template>

<xsl:template match="text()" mode="bookmarks">
	<xsl:value-of select="normalize-space(.)" />
</xsl:template>

<xsl:template match="div[@class='toc'][count(ancestor::scBlock) = 1]" mode="bookmarks">
	<bookmarks>
		<xsl:apply-templates mode="bookmarks"/>
	</bookmarks>
</xsl:template>

<xsl:template match="div[@class='toc'][count(ancestor::scBlock) = 1]//li" mode="bookmarks">
	<xsl:call-template name="bookmark"/>
</xsl:template>

<xsl:template name="bookmark">
	<bookmark name="{a}" href="{a/@href}">
		<xsl:apply-templates mode="bookmarks"/>
	</bookmark>
</xsl:template>


<xsl:template match="alternative"><xsl:apply-templates/></xsl:template>
<xsl:template match="@lookForAlt"><xsl:attribute name="alt"><xsl:value-of select="si(.='', ancestor::alternative/@alt, .)"/></xsl:attribute></xsl:template>	
	

<xsl:overlay match="/">
<xsl:for-each select="//scBasket">
<xsl:variable name="vKey" select="string(@key)"/>
<xsl:variable name="vUnicity" select="java:java.util.HashSet.new()"/>
<xsl:value-of select="java:put($vBasketPool, $vKey, lxslt:nodeset(//scTooltip[@basketKey=$vKey][java:add($vUnicity, string(@itemKey))]))"/> 
</xsl:for-each>	
</xsl:overlay>
<xsl:template match="scBasket">
<xsl:variable name="vClass" select="@widgetClass"/>
<xsl:variable name="vKey" select="string(@key)"/>
<xsl:variable name="vHasElts" select="boolean(java:get($vBasketPool, $vKey))"/>
<xsl:if test="$vHasElts or @suppressIfEmpty = 'no'">
<xsl:choose>
<xsl:when test="scBlock">
<div>
<xsl:attribute name="class"><xsl:value-of select="concat(@class,' ',$vClass)"/></xsl:attribute>
<xsl:variable name="vCount" select="count(ancestor::scBlock)+1"/>
<xsl:element name="{concat('h', si($vCount &gt; 6, '6', $vCount))}">
<xsl:apply-templates select="scBlock/hx/@*"/>
<xsl:apply-overlays select="scBlock/hx/node()"/>
<xsl:apply-templates select="scBlock/hx/node()"/>
</xsl:element>
<div>
<xsl:attribute name="class"><xsl:value-of select="addSuffixOnWords($vClass, '_co')"/></xsl:attribute>
<xsl:apply-templates select="." mode="scBasketList"/>
</div>
</div>
</xsl:when>
<xsl:when test="scBasketTitle">
<div>
<xsl:attribute name="class"><xsl:value-of select="concat(@class,' ',$vClass)"/></xsl:attribute>
<xsl:apply-overlays select="scBasketTitle/node()"/>
<xsl:apply-templates select="scBasketTitle/node()"/>
<div>
<xsl:attribute name="class"><xsl:value-of select="addSuffixOnWords($vClass, '_co')"/></xsl:attribute>
<xsl:apply-templates select="." mode="scBasketList"/>
</div>
</div>
</xsl:when>
<xsl:otherwise>
<xsl:apply-templates select="." mode="scBasketList"/>
</xsl:otherwise>
</xsl:choose>
</xsl:if>
</xsl:template>
<xsl:template match="scBasket" mode="scBasketList">
<xsl:variable name="vClass" select="@widgetClass"/>
<xsl:variable name="vKey" select="string(@key)"/>
<xsl:variable name="vChiTagName" select="si(@tagName='div','div','li')"/>
<xsl:element name="{@tagName}">
<xsl:choose>
<xsl:when test="scBlock|scBasketTitle">
<xsl:attribute name="class"><xsl:value-of select="addSuffixOnWords($vClass, '_li')"/></xsl:attribute>
</xsl:when>
<xsl:otherwise>
<xsl:attribute name="class"><xsl:value-of select="concat(@class,' ',$vClass)"/></xsl:attribute>
</xsl:otherwise>
</xsl:choose>
<xsl:choose>
<xsl:when test="@sort='byTitle'">
<xsl:for-each select="java:get($vBasketPool, $vKey)">
<xsl:sort select="scTooltipTitle" data-type="text"/>
<xsl:apply-templates select="." mode="scBasketItem">
<xsl:with-param name="vClass" select="$vClass"/>
<xsl:with-param name="vChiTagName" select="$vChiTagName"/>
</xsl:apply-templates>
</xsl:for-each>
</xsl:when>
<xsl:when test="@sort='byContent'">
<xsl:for-each select="java:get($vBasketPool, $vKey)">
<xsl:sort select="scTooltipContent" data-type="text"/>
<xsl:apply-templates select="." mode="scBasketItem">
<xsl:with-param name="vClass" select="$vClass"/>
<xsl:with-param name="vChiTagName" select="$vChiTagName"/>
</xsl:apply-templates>
</xsl:for-each>
</xsl:when>
<xsl:otherwise>
<xsl:for-each select="java:get($vBasketPool, $vKey)">
<xsl:apply-templates select="." mode="scBasketItem">
<xsl:with-param name="vClass" select="$vClass"/>
<xsl:with-param name="vChiTagName" select="$vChiTagName"/>
</xsl:apply-templates>
</xsl:for-each>
</xsl:otherwise>
</xsl:choose>
</xsl:element>
</xsl:template>
<xsl:template match="*" mode="scBasketItem">
<xsl:param name="vClass"/>
<xsl:param name="vChiTagName"/>
<xsl:choose>
<xsl:when test="local-name() = 'scTooltip'">
<xsl:variable name="vIdInBskt" select="concat(@basketKey, generate-id(.))"/>
<xsl:element name="{$vChiTagName}">
<xsl:attribute name="class"><xsl:value-of select="addSuffixOnWords($vClass, '_it')"/></xsl:attribute>
<xsl:attribute name="id"><xsl:value-of select="$vIdInBskt"/></xsl:attribute>
<div class="{addSuffixOnWords($vClass, '_itti')}">
<xsl:choose>
<xsl:when test="scTooltipTitle"><xsl:apply-templates select="scTooltipTitle/node()"/></xsl:when>
<xsl:otherwise><xsl:attribute name="style">display:none;</xsl:attribute></xsl:otherwise>
</xsl:choose>
</div>
<div class="{addSuffixOnWords($vClass, '_itco')}">
<xsl:choose>
<xsl:when test="scTooltipContent"><xsl:apply-templates select="scTooltipContent/node()"/></xsl:when>
<xsl:otherwise><xsl:attribute name="style">display:none;</xsl:attribute></xsl:otherwise>
</xsl:choose>
</div>
</xsl:element>		
</xsl:when>
</xsl:choose>
</xsl:template>
	

<xsl:variable name="vBufJs" select="java:java.lang.StringBuffer.new()"/>
<xsl:overlay match="body" mode="endTags" priority="100"><xsl:if test="java:length($vBufJs) &gt; 0"><script type="text/javascript"><xsl:value-of select="java:toString($vBufJs)"/></script></xsl:if></xsl:overlay>

	
<xsl:template match="scTooltip[@basketKey='equipIndex']" mode="scBasketList">
	<tr class="equip_it">
		<td class="equip_itti">
			<xsl:apply-templates select="scTooltipTitle/node()"/>
		</td>
		<td class="equip_itco">
			<xsl:apply-templates select="scTooltipContent/node()"/>
		</td>
		<td class="equip_itref">
			<xsl:variable name="vTargetId" select="span/idNode/@id"/>
			<xsl:variable name="vTarget" select="//div[scTooltip/span/idNode/@id=$vTargetId][1]"/>
			<xsl:for-each select="$vTarget">
				<xsl:for-each select="//eqplacecode[. = $vTarget/span/@data-place]">
					<a href="#{alphaHash(concat(., generate-id($vTarget)))}" />
				</xsl:for-each>
			</xsl:for-each>
		</td>
	</tr>
</xsl:template>
<!-- Add xhtml namespace to html tag -->
<xsl:template match="html">
  <xsl:element name="html" namespace="http://www.w3.org/1999/xhtml">
    <xsl:apply-templates select="@*" />
    <xsl:apply-overlays />
    <xsl:apply-templates />
  </xsl:element>
</xsl:template>


<xsl:variable name="vBasketPool" select="java:java.util.HashMap.new()"/>
	

<xsl:overlay match="*[parent::scTooltip/@basketKey and not(starts-with(local-name(),'scTooltip'))]" priority="1">
<xsl:variable name="vIdAnc" select="java:ensureIdOnCurrentResultElt($vDialog)"/>
<xsl:variable name="vTT" select="parent::scTooltip"/>
<xsl:variable name="vBasketKey" select="string($vTT/@basketKey)"/>
<xsl:variable name="vItemKey" select="string($vTT/@itemKey)"/>
<xsl:variable name="vIdInBskt" select="concat($vBasketKey, generate-id(java:get($vBasketPool, $vBasketKey)[@itemKey = $vItemKey][1]))"/>
<xsl:variable name="vTrigger">
<xsl:choose>
<xsl:when test="(boolean(descendant::a) or boolean(ancestor::a)) and $vTT/@trigger='onclick'">onmouseover</xsl:when>
<xsl:otherwise><xsl:value-of select="$vTT/@trigger"/></xsl:otherwise>
</xsl:choose>
</xsl:variable>
<xsl:if test="$vTT/@render = 'asTooltip' and boolean(//scBasket[@key=$vBasketKey])">
<xsl:value-of select="execute(java:append($vBufJs, concat('scTooltipMgr.registerTooltip(&quot;',$vIdAnc,'&quot;,&quot;',$vIdInBskt,'&quot;,&quot;',$vTrigger,'&quot;,&quot;',$vTT/@class,'&quot;,&quot;',$vTT/@classRoot,'&quot;,{',si($vTT/@basketLnk='no','NOREF:true,'),$vTT/@options,'});')))"/>
</xsl:if>
</xsl:overlay>
<xsl:template match="scTooltip">
<xsl:variable name="vKey" select="string(@basketKey)"/>
<xsl:choose>
<xsl:when test="@basketKey and boolean(//scBasket[@key=$vKey])">
<xsl:variable name="vItemKey" select="string(@itemKey)"/>
<xsl:variable name="vIdInBskt" select="concat($vKey, generate-id(java:get($vBasketPool, $vKey)[@itemKey = $vItemKey][1]))"/>
<xsl:variable name="vEltRank"><xsl:for-each select="java:get($vBasketPool, $vKey)"><xsl:value-of select="si(@itemKey = $vItemKey, position(), '')"/></xsl:for-each></xsl:variable>
<xsl:variable name="vRefAnc" select="si(//scBasket[@key=$vKey][1]/@tagName = 'ol',$vEltRank,'*')"/>
<xsl:for-each select="child::*[not(starts-with(local-name(),'scTooltip'))]">
<xsl:variable name="vTagName">
<xsl:choose>
<xsl:when test="boolean(descendant::a) or boolean(ancestor::a)">span</xsl:when>
<xsl:otherwise><xsl:value-of select="local-name()"/></xsl:otherwise>
</xsl:choose>
</xsl:variable>
<xsl:element name="{$vTagName}">
<xsl:for-each select="@*">
<xsl:apply-templates select="."/>
</xsl:for-each>
<xsl:if test="$vTagName = 'a' and @href = '#'"><xsl:attribute name="href">#<xsl:value-of select="$vIdInBskt"/></xsl:attribute></xsl:if>
<xsl:apply-overlays/>
<xsl:apply-templates/>
</xsl:element>
</xsl:for-each>
<xsl:if test="not(@basketLnk='no')">
<sup class="{addSuffixOnWords(@class, '_ref')}">
<xsl:choose>
<xsl:when test="boolean(ancestor::a)"><span>[</span><xsl:value-of select="$vRefAnc"/><span>]</span></xsl:when>
<xsl:otherwise><a href="#{$vIdInBskt}"><span>[</span><xsl:value-of select="$vRefAnc"/><span>]</span></a></xsl:otherwise>
</xsl:choose>
</sup>
</xsl:if>
</xsl:when>
<xsl:otherwise>
<xsl:variable name="vTTTitle"><redirect:serialize omit-xml-declaration="yes" method="html"><xsl:apply-templates select="scTooltipTitle/node()"/></redirect:serialize></xsl:variable>
<xsl:variable name="vTTContent"><redirect:serialize omit-xml-declaration="yes" method="html"><xsl:apply-templates select="scTooltipContent/node()"/></redirect:serialize></xsl:variable>
<xsl:variable name="vTTTrigger" select="@trigger"/>
<xsl:variable name="vTTAttr">scTooltipMgr.showTooltip(this,event,&quot;<xsl:value-of select="chaineProtegeJs(normalize-space($vTTContent))"/>&quot;,&quot;<xsl:value-of select="chaineProtegeJs(normalize-space($vTTTitle))"/>&quot;,&quot;<xsl:value-of select="@class"/>&quot;,&quot;<xsl:value-of select="@classRoot"/>&quot;,{<xsl:value-of select="@options"/>});</xsl:variable>
<xsl:for-each select="child::*[not(starts-with(local-name(),'scTooltip'))]">
<xsl:variable name="vTagName">
<xsl:choose>
<xsl:when test="boolean(descendant::a) or boolean(ancestor::a)">span</xsl:when>
<xsl:otherwise><xsl:value-of select="local-name()"/></xsl:otherwise>
</xsl:choose>
</xsl:variable>
<xsl:element name="{$vTagName}">
<xsl:attribute name="{si((boolean(descendant::a) or boolean(ancestor::a)) and $vTTTrigger='onclick','onmouseover',$vTTTrigger)}"><xsl:value-of select="$vTTAttr"/></xsl:attribute>
<xsl:apply-templates select="@*"/>
<xsl:apply-overlays/>
<xsl:apply-templates/>
</xsl:element>
</xsl:for-each>
</xsl:otherwise>
</xsl:choose>
</xsl:template>
	

<xsl:template match="scBlock"><div><xsl:apply-templates select="@*"/><xsl:apply-overlays/><xsl:apply-templates/></div></xsl:template>
<xsl:template match="scBlock/@noLocalOutline"/>
<xsl:template match="scBlockTitle"/>
	

			<!-- Déclaration d'une clé pour récupéré facilement tout les éléments avec @itemKey (scTooltip et titre des items) -->
<xsl:key name="items" match="*[@itemKey]" use="@itemKey" />

<!-- Surcharge du scTooltip pour ne générer qu'un span vide avec id et le labelTitle (aucun n'a de contenu de propre) -->
<xsl:template match="scTooltip" priority="1">
	<xsl:variable name="vTitle" select="span/addAttribute[@name='title']/span" />
	<span id="{generate-id(.)}" title="{$vTitle}" class="{span/@class}" />
</xsl:template>

<!-- Pour les tooltips de type 'items' (référence interne), on recherche le span crée dans les titres des scBlock -->
<xsl:template match="scTooltip[@basketKey='items']" priority="1">
	<xsl:variable name="vTarget" select="key('items', @itemKey)[self::span]" />
	<xsl:variable name="vTitle" select="span/addAttribute[@name='title']/span" />
	<xsl:choose>
		<xsl:when test="$vTarget">
			<a href="#{alphaHash(@itemKey)}" title="{$vTitle}" class="{span/@class}" />
		</xsl:when>
		<xsl:otherwise>
			<span title="{$vTitle}" class="{span/@class}" />
		</xsl:otherwise>
	</xsl:choose> 
</xsl:template>

<!-- Génération de la liste de l'index -->
<xsl:template match="scBasket" mode="scBasketList" priority="1" xmlns:xalan="http://xml.apache.org/xalan">
	<xsl:variable name="vClass" select="@widgetClass" />

	<!-- Passage par un XML intérmédiaire pour effectuer le tri des tooltips, nécessaire au groupement par première lettre -->
	<xsl:variable name="vSortedTooltips">
		<root>
			<xsl:for-each select="java:get($vBasketPool, string(@key))">
				<xsl:sort select="normalize-space(scTooltipTitle)" data-type="text"/>
				<xsl:copy-of select="." />
			</xsl:for-each>
		</root>
	</xsl:variable>

	<xsl:for-each select="xalan:nodeset($vSortedTooltips)/root/*">
		<xsl:variable name="vFirstLetter" select="substring(normalize-space(scTooltipTitle), 1, 1)" />
		<xsl:variable name="vPrecFirstLetter" select="substring(normalize-space((preceding-sibling::*[1])/scTooltipTitle), 1, 1)" />
		<xsl:if test="$vFirstLetter != $vPrecFirstLetter">
			<div class="{$vClass}_grpti">
				<xsl:value-of select="java:toUpperCase($vFirstLetter)" />
			</div>
		</xsl:if>
		<xsl:apply-templates select="." mode="scBasketItem">
			<xsl:with-param name="vClass" select="$vClass"/>
		</xsl:apply-templates>
	</xsl:for-each>
</xsl:template>

<xsl:template match="scTooltip" mode="scBasketItem" priority="1" xmlns:xalan="http://xml.apache.org/xalan">
	<xsl:param name="vClass"/>
	
	<!-- Passage par un XML intérmédiaire pour créer une liste triée des scBlocks contenant un tooltip de même itemKey -->
	<xsl:variable name="vItemTargets">
		<root>
			<xsl:for-each select="key('items', @itemKey)">
				<xsl:variable name="vTitle" select="(ancestor::scBlock[containWord(@class, 'item')][1])/ifText/hx/span" />
				<item title="{normalize-space($vTitle)}" itemKey="{$vTitle/span/@itemKey}" />
			</xsl:for-each>
		</root>
	</xsl:variable>
	
	<li class="{$vClass}_it">
		<div class="{$vClass}_itti">
			<xsl:apply-templates select="scTooltipTitle/node()"/>
		</div>
		<div class="{$vClass}_itco">
			<xsl:apply-templates select="scTooltipContent/node()"/>
		</div>
		<xsl:copy-of select="xalan:nodeset($vItemTargets)/root/" />
		<ul class="{$vClass}_itrefs">
			<xsl:for-each select="xalan:nodeset($vItemTargets)/root/*">
				<xsl:if test="not(preceding-sibling::*/@itemKey = @itemKey)">
					<li class="{$vClass}_itref">
						<span>
							<xsl:value-of select="@title" />
						</span>
						<a class="itemRef_a" href="#{alphaHash(@itemKey)}" />
					</li>
				</xsl:if>
			</xsl:for-each>
		</ul>
	</li>
</xsl:template>
<xsl:template match="div[@class='nonRedundantList']">
    <xsl:apply-templates />
</xsl:template>

<xsl:template match="div[@class='nonRedundantList']/*">
    <xsl:if test="not(preceding-sibling::*[normalize-space(.) = normalize-space(current())])">
        <xsl:copy>
            <xsl:apply-templates select="node() | @*" />
        </xsl:copy>
    </xsl:if> 
</xsl:template>

			<xsl:template match="div[@class='toc'][count(ancestor::scBlock) = 1]">
	<xsl:copy>
		<xsl:apply-templates select="@*"/>
		<xsl:attribute name="id">rootToc</xsl:attribute>
		<xsl:apply-templates select="node()" />
	</xsl:copy>
</xsl:template>


<xsl:template match="/"><xsl:apply-overlays/><xsl:apply-templates select="node()"/></xsl:template>
<xsl:template match="body">
<xsl:copy>
<xsl:apply-templates select="@*"/>
<xsl:apply-overlays select="." mode="startTags"/>
<xsl:apply-overlays/>
<xsl:apply-templates/>
<xsl:apply-overlays select="." mode="endTags"/>
</xsl:copy>
</xsl:template>
<xsl:template match="zoneContent"><xsl:apply-overlays/><xsl:apply-templates/></xsl:template>
<xsl:template match="ifText"><xsl:if test="descendant::text()[string-length(normalize-space())&gt;0] or descendant::img or descendant::object"><xsl:apply-templates/></xsl:if></xsl:template>
<xsl:template match="hx"><xsl:variable name="vCount" select="count(ancestor::scBlock)"/><xsl:element name="{concat('h', si($vCount &gt; 6, '6', $vCount))}"><xsl:apply-templates select="@*"/><xsl:apply-overlays/><xsl:apply-templates/></xsl:element></xsl:template>
<xsl:template match="addAttribute">
<xsl:variable name="vAttCo"><xsl:choose><xsl:when test="@filter='textOnly'"><xsl:value-of select="normalize-space(.)"/></xsl:when><xsl:otherwise><redirect:serialize omit-xml-declaration="yes"><xsl:value-of select="."/></redirect:serialize></xsl:otherwise></xsl:choose></xsl:variable>
<xsl:choose>
<xsl:when test="@name = 'lookForAlt'">
<xsl:attribute name="alt"><xsl:value-of select="si(string($vAttCo)='', ancestor::alternative/@alt, $vAttCo)" disable-output-escaping="yes"/></xsl:attribute>
</xsl:when>
<xsl:otherwise>
<xsl:attribute name="{@name}"><xsl:value-of select="$vAttCo" disable-output-escaping="yes"/></xsl:attribute>
</xsl:otherwise>
</xsl:choose>
</xsl:template>
	

<xsl:template match="crossRef"/>
<xsl:overlay match="*[crossRef]" priority="1">
<xsl:variable name="vId" select="java:ensureIdOnCurrentResultElt($vDialog, string(crossRef[@prefId]/@prefId))"/>
<xsl:for-each select="crossRef/entry"><xsl:value-of select="java:com.scenari.m.ge.generator.web.CrossRefEntry.addEntry($vDialog, $vId, @keyRef, @value)"/></xsl:for-each>
</xsl:overlay>
	
	<xsl:template match="* | processing-instruction() | comment()"><xsl:copy><xsl:apply-templates select="@*"/><xsl:apply-overlays/><xsl:apply-templates/></xsl:copy></xsl:template>
	<xsl:template match="@* | text()"><xsl:copy/></xsl:template>
</xsl:stylesheet>
