<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns="http://www.w3.org/1999/xhtml"
    xmlns:ht="http://www.w3.org/1999/xhtml" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:lxslt="http://xml.apache.org/xslt" xmlns:redirect="com.scenari.xsldom.xalan.lib.Redirect"
    xmlns:java="http://xml.apache.org/xslt/java" exclude-result-prefixes="ht" extension-element-prefixes="redirect java lxslt ">
    <xsl:output method="xml" indent="no" />
    <xsl:param name="vDialog" />
    <xsl:param name="vAgent" />
    
    <xsl:template match="ht:alternative">
        <xsl:apply-templates />
    </xsl:template>
    
    <xsl:template match="@lookForAlt">
        <xsl:attribute name="alt">
            <xsl:value-of select="si(.='', ancestor::ht:alternative/@alt, .)" />
        </xsl:attribute>
    </xsl:template>
    
    <xsl:template match="/">
        <xsl:apply-overlays />
        <xsl:apply-templates select="node()" />
    </xsl:template>
    
    <xsl:template match="ht:body">
        <xsl:copy>
            <xsl:apply-templates select="@*" />
            <xsl:apply-overlays />
            <xsl:apply-templates />
            <xsl:apply-overlays select="." mode="endTags" />
        </xsl:copy>
    </xsl:template>
    
    <xsl:template match="ht:zoneContent">
        <xsl:apply-overlays />
        <xsl:apply-templates />
    </xsl:template>
    
    <xsl:template match="ht:ifText">
        <xsl:if
            test="descendant::text()[string-length(normalize-space())&gt;0] or descendant::ht:img or descendant::ht:object">
            <xsl:apply-templates />
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="ht:hx">
        <xsl:variable name="vCount" select="count(ancestor::ht:scBlock)" />
        <xsl:element name="{concat('h', si($vCount &gt; 6, '6', $vCount))}">
            <xsl:apply-templates select="@*" />
            <xsl:apply-overlays />
            <xsl:apply-templates />
        </xsl:element>
    </xsl:template>
    
    <xsl:template match="ht:addAttribute">
        <xsl:variable name="vAttCo">
            <xsl:choose>
                <xsl:when test="@filter='textOnly'">
                    <xsl:value-of select="normalize-space(.)" />
                </xsl:when>
                <xsl:otherwise>
                    <redirect:serialize omit-xml-declaration="yes">
                        <xsl:value-of select="." />
                    </redirect:serialize>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:choose>
            <xsl:when test="@name = 'lookForAlt'">
                <xsl:attribute name="alt">
                    <xsl:value-of
                        select="si(string($vAttCo)='', ancestor::ht:alternative/@alt, $vAttCo)"
                        disable-output-escaping="yes" />
                </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <xsl:attribute name="{@name}">
                    <xsl:value-of select="$vAttCo" disable-output-escaping="yes" />
                </xsl:attribute>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:overlay
        match="*[parent::scTooltip/@basketKey and not(starts-with(local-name(),'scTooltip'))]"
        priority="1">
        <xsl:variable name="vIdAnc" select="java:ensureIdOnCurrentResultElt($vDialog)" />
        <xsl:variable name="vTT" select="parent::ht:scTooltip" />
        <xsl:variable name="vBasketKey" select="$vTT/@basketKey" />
        <xsl:variable name="vIdInBskt" select="concat($vBasketKey,$vTT/@itemKey)" />
        <xsl:if test="$vTT/@render = 'asTooltip' and count(//ht:scBasket[@key=$vBasketKey])>0">
            <xsl:value-of
                select="execute(java:append($vBufJs, concat('scTooltipMgr.registerTooltip(&quot;',$vIdAnc,'&quot;,&quot;',$vIdInBskt,'&quot;,&quot;',$vTT/@trigger,'&quot;,&quot;',$vTT/@class,'&quot;,&quot;',$vTT/@classRoot,'&quot;,{',$vTT/@options,'});')))"
            />
        </xsl:if>
    </xsl:overlay>
    
    <xsl:template match="ht:scTooltip">
        <xsl:variable name="vKey" select="string(@basketKey)" />
        <xsl:choose>
            <xsl:when test="@basketKey and count(//ht:scBasket[@key=$vKey])>0">
                <xsl:apply-overlays />
                <xsl:apply-templates
                    select="text()|child::*[not(starts-with(local-name(),'scTooltip'))]" />
                <xsl:variable name="vItemKey" select="string(@itemKey)" />
                <xsl:variable name="vIdInBskt" select="concat(@basketKey, @itemKey)" />
                <xsl:variable name="vEltRank">
                    <xsl:for-each select="java:get($vBasketPool, $vKey)">
                        <xsl:value-of select="si(@itemKey = $vItemKey, position(), '')" />
                    </xsl:for-each>
                </xsl:variable>
                <xsl:variable name="vRefAnc"
                    select="si(//ht:scBasket[@key=$vKey][1]/@tagName = 'ol',$vEltRank,'*')" />
                <sup class="{addSuffixOnWords(@class, '_ref')}">
                    <a href="#{$vIdInBskt}">
                        <xsl:value-of select="$vRefAnc" />
                    </a>
                </sup>
            </xsl:when>
            <xsl:otherwise>
                <xsl:variable name="vTTTitle">
                    <redirect:serialize omit-xml-declaration="yes" method="xml">
                        <xsl:apply-templates select="ht:scTooltipTitle/node()" />
                    </redirect:serialize>
                </xsl:variable>
                <xsl:variable name="vTTContent">
                    <redirect:serialize omit-xml-declaration="yes" method="xml">
                        <xsl:apply-templates select="ht:scTooltipContent/node()" />
                    </redirect:serialize>
                </xsl:variable>
                <xsl:variable name="vTTTrigger" select="@trigger" />
                <xsl:variable name="vTTAttr"
                    >scTooltipMgr.showTooltip(this,event,&quot;<xsl:value-of
                        select="chaineProtegeJs(normalize-space($vTTContent))"
                    />&quot;,&quot;<xsl:value-of
                        select="chaineProtegeJs(normalize-space($vTTTitle))"
                    />&quot;,&quot;<xsl:value-of select="@class"
                    />&quot;,&quot;<xsl:value-of select="@classRoot"
                    />&quot;,{<xsl:value-of select="@options" />});</xsl:variable>
                <xsl:for-each select="child::*[not(starts-with(local-name(),'scTooltip'))]">
                    <xsl:copy>
                        <xsl:attribute name="{$vTTTrigger}">
                            <xsl:value-of select="$vTTAttr" />
                        </xsl:attribute>
                        <xsl:apply-templates select="@*" />
                        <xsl:apply-overlays />
                        <xsl:apply-templates />
                    </xsl:copy>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:variable name="vBufJs" select="java:java.lang.StringBuffer.new()" />
    <xsl:overlay match="ht:body" mode="endTags">
        <xsl:if test="java:length($vBufJs) &gt; 0">
            <script type="text/javascript"><xsl:value-of select="java:toString($vBufJs)" /></script>
        </xsl:if>
    </xsl:overlay>
    
    <xsl:variable name="vBasketPool" select="java:java.util.HashMap.new()" />
    
    <xsl:template match="ht:scBlock">
        <div>
            <xsl:apply-templates select="@*" />
            <xsl:apply-overlays /> 
            <xsl:apply-templates select="*[1]" />
	    <xsl:apply-templates select="*[2]/*" />
        </div>
    </xsl:template>
    
    <xsl:template match="ht:scBlockTitle" />
    
    <xsl:template match="ht:crossRef" />
    <xsl:overlay match="*[ht:crossRef]" priority="1">
        <xsl:variable name="vId"
            select="java:ensureIdOnCurrentResultElt($vDialog, string(ht:crossRef[@prefId]/@prefId))" />
        <xsl:for-each select="ht:crossRef/ht:entry">
            <xsl:value-of
                select="java:com.scenari.m.ge.generator.web.CrossRefEntry.addEntry($vDialog, $vId, @keyRef, @value)"
            />
        </xsl:for-each>
    </xsl:overlay>
    
    <xsl:template match="* | processing-instruction() | comment()">
        <xsl:copy>
            <xsl:apply-templates select="@*" />
            <xsl:apply-overlays />
            <xsl:apply-templates />
        </xsl:copy>
    </xsl:template>
    
    <xsl:template match="ht:div[@class='nonRedundantList']">
        <xsl:apply-templates mode="nonRedundant" />
    </xsl:template>
    
    <xsl:template match="ht:div[@class='nonRedundantList']/ht:*" mode="nonRedundant">
        <xsl:copy>
            <xsl:copy-of select="@*" />
            <xsl:apply-templates mode="nonRedundant" />
        </xsl:copy>
    </xsl:template> 
    
    <xsl:template match="ht:div[@class='nonRedundantList']/ht:*/ht:*" mode="nonRedundant">
        <xsl:if test="not(preceding-sibling::ht:*[normalize-space(.) = normalize-space(current())])">
            <xsl:copy>
                <xsl:apply-templates select="node() | @*" />
            </xsl:copy>
        </xsl:if> 
    </xsl:template>
    
    
    <xsl:template match="ht:scBlock[normalize-space(@class) = 'indicators']">
        <xsl:variable name="vContent">
            <xsl:apply-templates select="ht:div/*" />
        </xsl:variable>
        <xsl:if test="string-length($vContent)">
            <div>
                <xsl:apply-templates select="@* | *[not(self::ht:div)]" />
                <xsl:copy-of select="$vContent" />
            </div> 
        </xsl:if> 
    </xsl:template>
    
    <xsl:template match="ht:div[normalize-space(@class) = 'indicators_co']">
        <xsl:variable name="vIndicActive">
            <xsl:apply-templates select="ht:table" />
        </xsl:variable>
        <xsl:variable name="vIndicPotential">
            <xsl:apply-templates select="ht:scBlock" />
        </xsl:variable>
        <xsl:if test="string-length($vIndicActive) or string-length($vIndicPotential)">
            <xsl:copy>
                <xsl:apply-templates select="@*" />
                <xsl:if test="string-length($vIndicActive)">
                    <xsl:copy-of select="$vIndicActive" />
                </xsl:if>
                <xsl:if test="string-length($vIndicPotential)">
                    <xsl:copy-of select="$vIndicPotential" />
                </xsl:if>
            </xsl:copy> 
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="ht:table[contains(@class, 'indicActiveTable')]">
        <xsl:if test="ht:tr/ht:td">
            <xsl:copy>
                <xsl:apply-templates select="node() | @*" />
            </xsl:copy>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="ht:scBlock[normalize-space(@class) = 'indicPotential']">
        <xsl:if test="ht:div/ht:ul/ht:li">
            <div>
                <xsl:apply-templates select="node() | @*" />
            </div>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="@* | text()">
        <xsl:copy />
    </xsl:template>
</xsl:stylesheet>
